<?php

namespace Drupal\simple_trash\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

class TrashPermanentDeleteForm extends ConfirmFormBase
{

  protected string $entity_type;
  protected int $entity_id;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'trash_permanent_delete_confirm_form';
  }

  public function getQuestion()
  {
    return $this->t('Are you sure you want to delete the %entity_type : %entity permanently?', ['%entity_type' => $this->entity_type, '%entity' => $this->entity_id]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('system.admin_content');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $entity_type = \Drupal::routeMatch()->getParameter('entity_type');
    $entity_id = \Drupal::routeMatch()->getParameter('entity');
    $this->entity_type = $entity_type;
    $this->entity_id = $entity_id;
    $entity = \Drupal::entityTypeManager()->getStorage($entity_type)->load($entity_id);
    if (empty($entity)) {
      $form['message'] = [
        '#type' => 'markup',
        '#markup' => $this->t('This entity did not exist or has already been deleted permanently.'),
      ];
      return $form;
    } elseif (!$entity->trash->value) {
      $form['message'] = [
        '#type' => 'markup',
        '#markup' => $this->t('This entity is not in trash, You can\'t deleted it permanently.'),
      ];
      return $form;
    } else {
      return parent::buildForm($form, $form_state);
    }
  }

  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    $entity_type_storage = \Drupal::entityTypeManager()->getStorage($this->entity_type);
    $entity = $entity_type_storage->load($this->entity_id);
    $label = $entity->label();
    $entity_type_storage->delete([$entity], true);
    \Drupal::messenger()->addWarning($this->t('The entity %label has been deleted permanently.', ['%label' => $label]));
  }
}
